c     This is file "venus_ntuple_ana.f" for use with VENUS data. It
c     produces a ntuple with data relevant for BRAHMS project.
c
c     It should be compiled either using "make_venus.sh" or by saying
c
c     This code should be compiled and linked with
c         f77  -static -o rdzevt.o venus_hist_ana venus_hist_ana.f\
c           -L/usr/group/utility/event/eg/pro/lib -leglib\
c           -L/cern/new/lib -lpacklib \
c     where 'rdzevt.o' shoulde be a link to      
c         /usr/group/utility/event/eg/pro/lib/rdzevt.o
c     on host sgs0.hirg.bnl.gov
c      
c     'tape1' should be a link to
c         /rhic_data/data/venus/auau_venus.dat      
c     
c     Notice, "event.inc" should be in the same directory as this source
c     code. This is best done, if it is a link to
c     "/usr/group/utility/event/eg/pro/src/event.inc" 
c
c     When run, "tape1" should be a link, residing in the same
c     directory, pointing to "/rhic_data/data/venus/auau_venus.dat"
c
c     Created by Christian Holm <cholm@nbi.dk> on Feb. 27. 1998
c     Changes:
c
c     Three entries is used, namely
c
c        aninit anuser anfin
c
c     These are used in r...o
c     
      
      subroutine aninit
      implicit none
      include 'event.inc'
      
      integer event, g_id, part_f, part_type(50), ip, istat, icycle 
      real m_0, p_x, p_y, p_z, p_t, rap, m_t, part_dat(11), eta, imp 

*     --------------------------------------------------------------
      real gapl, gaph, gapw, dist, B, ang, dt, c
      parameter (gapl = 0.5, gaph = 0.1, gapw = 0.25, dist = 2.65)
      parameter (B = 1.2, ang = 0.5236, dt = 0.1)

      integer hit, nhit, rotphi, count
      real the, ph, R, t, t0, w, cx, cy, cz, m, x, z
      real v, vt, vx, vy, vz, p, gamma, tin
*     --------------------------------------------------------------
      
      character*6 part_nam(12)
      save event
      data part_nam /'event', 'b', 'g_id', 'm_0', 'p_x', 'p_y',
     $     'p_z', 'rap', 'eta','m_t', 'p_t', 'theta' /
      
      integer hmemor
      common /pawc/ hmemor( 200000 )
      call hlimit( 200000 )

      call hropen(10,'NTUPLE','venus_mids.hbook','N',1024,istat)
      if(istat.ne.0) then 
         type *, 'Error in opening hbook file'
         goto 6000
      endif
      
c     I'm not sure about this part. I think the first line should be
c     enough, and then before "hfnt()" the variables "part_dat(1--10)"
c     should be se to appropiate values. Otherwise, the second form
c     should also be fine. In this way, the variables "event,...,pt"
c     should be set bofre "hfnt()", and the right dat will be shipped
c     out to the ntuple. The first form implies a definiton of
c     "part_nam" as a "charecter...data" structure.
      
      call hbooknc(1,'VENUS data',10,'Venus1',part_dat,part_nam)
      bmin=0
      bmax=14
      return

      entry anuser
      
      event = event + 1
      imp = bimevt
      write(6,fmt='(A,I2.1,F10.5)') 'Event# ', event, imp
      
      do ip = 1 , nptls
         
         if((gtype(ip).ge.6.and.gtype(ip).lt.19).or.gtype(ip).eq.25)
     $        then  
            
            g_id = gtype(ip)
            m_0  = mass(ip)
            p_x  = px(ip)
            p_y  = py(ip)
            p_z  = pz(ip)
            rap  = y(ip)

            eta = tan(theta(ip)/2.0) ! calculate psudo rapidity
            if(eta.le.0) then
               eta = 10.0
            else
               eta = - log(eta)
            endif
         
            m_t = sqrt(mass(ip)**2+pt(ip)**2)
            p_t = pt(ip)
*           ---------------------------------------------------
            p = sqrt(p_x**2+p_y**2+p_z*2)
            the = theta(ip)
            ph = asin(p_x/p_t)
            
            do rotphi = -89, 90
               hit = 0
               nhit = 0

*     Foerste test: 
*     Ligger PHI indenfor +/- 0.91 grad (bagest i GAP)
*     Ligger THE indenfor +/- 2.70 grad (forest i GAP) 
               if ((abs(ph-rotphi/90*3.1416).lt.0.0159).and.
     $             (abs(the-ang).lt.0.0471)) then
                  v = (p/m_0)/sqrt(1+(p/m_0)**2)
                  vx = v*sin(the)*cos(ph)
                  vz = v*cos(the)
    
                  gamma = 1/sqrt(1-v**2)
                  m = m_0 * gamma

                  tin = dist/(sin(the)*vx+cos(the)*vz)

                  R = 3.132 / B * sqrt(vx**2+vz**2) * gamma
                  w = sqrt(vx**2+vz**2) / R
                  t0 = ang / w
                  t = 0

*     Anden test:
*     Er radius R stoerre end magnetens laengde
                  if (R.gt.gapl) then
 100                 continue
                     t = t + dt
                     x = (vx*tin+R*cos(ang)) - (R*cos(w*(t+t0)))
                     z = (vz*tin-R*sin(ang)) + (R*sin(w*(t+t0)))
*     Tredje test:
*     Er partiklen efter hver skridt indenfor GAP'ets sider
                     if (abs(x*cos(ang)-z*sin(ang)).gt.gapw/2) then
                        goto 110
                     endif

*     Undersoeg, om partiklen er igennem magneten
                     if ((x*sin(ang)+z*cos(ang)).gt.dist+gapl) then
                        hit = 1
                        nhit = nhit + 1
                        
                        part_dat(1)  = event 
                        part_dat(2)  = imp
                        part_dat(3)  = gtype(ip)
                        part_dat(4)  = mass(ip)
                        part_dat(5)  = px(ip)
                        part_dat(6)  = py(ip)
                        part_dat(7)  = pz(ip)
                        part_dat(8)  = rap
                        part_dat(9)  = eta
                        part_dat(10) = p_t
                        part_dat(11) = m_t
                        part_dat(12) = theta(ip)
               
                        call hfnt(1)

                        goto 110
                     endif

                     goto 100

 110              continue

                  endif
               endif
            enddo
                  
*           ---------------------------------------------------

            if (hit.eq.5) then
               part_dat(1)  = event 
               part_dat(2)  = imp
               part_dat(3)  = gtype(ip)
               part_dat(4)  = mass(ip)
               part_dat(5)  = px(ip)
               part_dat(6)  = py(ip)
               part_dat(7)  = pz(ip)
               part_dat(8)  = rap
               part_dat(9)  = eta
               part_dat(10) = p_t
               part_dat(11) = m_t
               part_dat(12) = theta(ip)
               
               call hfnt(1)
            endif
            
         endif
         
         part_type(gtype(ip)) = part_type(gtype(ip)) + 1

      enddo
      
      return
      
      entry anfin
      
      call hrout(1,icycle,' ')
      call hrend('NTUPLE')
      
      do ip=1,50
         if(part_type(ip).gt.0) then
            type *, "particles (geant id, number)", ip, part_type(ip)
         endif
      enddo
      
 6000 write(6,*) 'Done making venus_mids.hbook'

      return
      end
      
c     Local Variables:
c     eval: (abbrev-mode 1)
c     eval: (fortran-auto-fill-mode 1)
c     eval: (local-set-key "\C-m" 'fortran-indent-new-line)
c     eval: (local-set-key "\M-\C-m" 'fortran-split-line)
c     eval: (font-lock-mode 1)
c     End:

c     end of file 'venus_nt_ana.f

